"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
exports.__esModule = true;
exports.default = exports.CheckToggle = void 0;
var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));
var _react = _interopRequireWildcard(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _CheckToggleSt = require("./CheckToggle.st.css");
var _constants = require("./constants");
var _Tooltip = _interopRequireDefault(require("../Tooltip"));
var _TooltipCommon = require("../common/PropTypes/TooltipCommon");
var _Focusable = require("../common/Focusable");
var _wixUiIconsCommon = require("@wix/wix-ui-icons-common");
var _context = require("../WixStyleReactProvider/context");
var _jsxFileName = "/home/builduser/work/2084893ac9ffd449/packages/wix-style-react/dist/cjs/CheckToggle/CheckToggle.tsx";
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
var icon = {
  small: /*#__PURE__*/_react.default.createElement(_wixUiIconsCommon.ConfirmSmall, {
    __self: void 0,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 13,
      columnNumber: 10
    }
  }),
  medium: /*#__PURE__*/_react.default.createElement(_wixUiIconsCommon.Confirm, {
    __self: void 0,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 14,
      columnNumber: 11
    }
  })
};

/** CheckToggle */
class CheckToggle extends _react.PureComponent {
  constructor() {
    super(...arguments);
    this.state = {
      checked: !!this.props.checked
    };
    /**
     * Checks if the component is controlled or uncontrolled.
     * The component is controlled only if prop checked is provided.
     *
     * @returns boolean
     * @private
     */
    this._isControlled = () => {
      return this.props.hasOwnProperty('checked');
    };
    /**
     * Toggles checked state and triggers the onChange callback.
     * Except when disabled
     */
    this._handleChange = changeEvent => {
      var {
        checked
      } = this.state;
      var {
        onChange
      } = this.props;
      this.setState({
        checked: !checked
      }, () => {
        if (onChange) onChange(changeEvent);
      });
    };
    /**
     * Renders the toggle itself
     * @returns React.ReactNode
     * @private
     */
    this._renderInput = () => {
      var {
        checked
      } = this._isControlled() ? this.props : this.state;
      var {
        size,
        disabled,
        onChange
      } = this.props;
      if (!size) return null;
      return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement("input", {
        type: "checkbox",
        className: _CheckToggleSt.classes.input,
        "data-hook": _constants.dataHooks.toggle,
        checked: checked,
        disabled: disabled,
        onChange: this._isControlled() ? onChange : this._handleChange,
        __self: this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 84,
          columnNumber: 9
        }
      }), /*#__PURE__*/_react.default.createElement("span", {
        className: _CheckToggleSt.classes.toggle,
        __self: this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 92,
          columnNumber: 9
        }
      }, icon[size]));
    };
    /**
     * Renders a tooltip wrapper
     * @returns React.ReactNode
     * @private
     */
    this._renderTooltip = () => {
      var {
        tooltipContent,
        tooltipProps
      } = this.props;
      return /*#__PURE__*/_react.default.createElement(_Tooltip.default, (0, _extends2.default)({
        dataHook: _constants.dataHooks.tooltip,
        content: tooltipContent
      }, tooltipProps, {
        __self: this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 105,
          columnNumber: 7
        }
      }), this._renderInput());
    };
  }
  render() {
    var {
      checked
    } = this._isControlled() ? this.props : this.state;
    var {
      dataHook,
      size,
      skin,
      disabled,
      tooltipContent,
      focusableOnFocus,
      focusableOnBlur,
      className
    } = this.props;
    return /*#__PURE__*/_react.default.createElement(_context.WixStyleReactContext.Consumer, {
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 129,
        columnNumber: 7
      }
    }, _ref => {
      var {
        newColorsBranding
      } = _ref;
      return /*#__PURE__*/_react.default.createElement("label", {
        className: (0, _CheckToggleSt.st)(_CheckToggleSt.classes.root, {
          checked,
          size,
          skin,
          disabled,
          newColorsBranding
        }, className),
        "data-hook": dataHook,
        onFocus: focusableOnFocus,
        onBlur: focusableOnBlur,
        __self: this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 131,
          columnNumber: 11
        }
      }, tooltipContent ? this._renderTooltip() : this._renderInput());
    });
  }
}
// @ts-ignore
exports.CheckToggle = CheckToggle;
CheckToggle.displayName = 'CheckToggle';
CheckToggle.propTypes = {
  dataHook: _propTypes.default.string,
  className: _propTypes.default.string,
  checked: _propTypes.default.bool,
  onChange: _propTypes.default.func,
  disabled: _propTypes.default.bool,
  size: _propTypes.default.oneOf(Object.values(_constants.SIZE)),
  skin: _propTypes.default.oneOf(Object.values(_constants.SKIN)),
  tooltipContent: _propTypes.default.node,
  tooltipProps: _propTypes.default.shape(_TooltipCommon.TooltipCommonProps),
  focusableOnFocus: _propTypes.default.func,
  focusableOnBlur: _propTypes.default.func
};
CheckToggle.defaultProps = {
  disabled: false,
  size: 'small',
  skin: 'standard'
};
var _default = exports.default = (0, _Focusable.withFocusable)(CheckToggle);
//# sourceMappingURL=CheckToggle.js.map