"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
exports.__esModule = true;
exports.default = void 0;
var _react = _interopRequireDefault(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _reactDnd = require("react-dnd");
var _DragUtils = require("../DragUtils");
var _types = require("../types");
var _jsxFileName = "/home/builduser/work/2084893ac9ffd449/packages/wix-style-react/dist/cjs/DragAndDrop/Draggable/components/Container.js";
/* eslint-disable new-cap */

var getRelativePositions = (child, parent) => {
  var topPositionOfChild = child.getBoundingClientRect().top - parent.getBoundingClientRect().top;
  var bottomPositionOfChild = topPositionOfChild + child.getBoundingClientRect().height;
  return {
    top: topPositionOfChild,
    bottom: bottomPositionOfChild
  };
};
var target = {
  drop(props, monitor) {
    /** if drop was already done(on child), we skip this drop call */
    if (monitor.getDropResult()) {
      return;
    }
    return {
      containerId: props.containerId,
      groupName: props.groupName,
      index: monitor.getItem().index
    };
  },
  canDrop(props) {
    return props.droppable;
  },
  hover(props, monitor, component) {
    if (!component) {
      return;
    }
    /**
      in this block we check that user dragging item over container empty pars
      and not over other draggable(sortable items)
    */
    var {
      top,
      bottom
    } = getRelativePositions(component.childNode, component.rootNode);
    var {
      hoverClientY
    } = (0, _DragUtils.dragCoordinates)({
      monitor,
      component
    });
    var isHoverInBannedArea = hoverClientY > top && hoverClientY < bottom || !monitor.isOver();
    if (isHoverInBannedArea) {
      return;
    }
    /** end of block */

    /**
      in this block we check, that user dragging item(from some container with group)
      over container with same group
    */
    var monitorItem = monitor.getItem();
    var isSameGroup = props.groupName && monitorItem.groupName && props.groupName === monitorItem.groupName;
    if (!props.droppable || !isSameGroup || !component) {
      return;
    }
    /** end of block */
    var dragIndex = monitorItem.index; // position of item that we drag in items array
    var hoverIndex = hoverClientY < top ? 0 : props.total; // if user drag item above other items - add to the top, otherwise - add to the bottom
    var isSameContainer = props.containerId === monitorItem.realTime.containerId; // check do we hover over same container(from which item is)

    /** in case that we hover over itself - do nothing */
    if (!component || hoverIndex === dragIndex && isSameContainer) {
      return;
    }

    /**
      if item is from same group but different container, that's mean that we move item
      from one container to another, and we need to move out item from previous container
    */
    if (isSameGroup && !isSameContainer) {
      monitorItem.realTime.onMoveOut(monitorItem.id);
    }
    /**
      as react-dnd store same snapshot in monitor(so containerId of item will be same, even if we moved it with hover to another container)
      after any hovers, we need to save also real position of monitor, with real links to current container
    */
    monitorItem.realTime.onMoveOut = props.onMoveOut;
    monitorItem.realTime.onDrop = props.onDrop;
    monitorItem.realTime.containerId = props.containerId;
    /**
      call callback, to ask parent to do some action, for example swap items or add new one,
      we send original position of item and new one, also id of item and original item state(
        it required for case, when we moving item from 1 container to another
      )
    */
    props.onHover({
      removedIndex: dragIndex,
      addedIndex: hoverIndex,
      id: monitorItem.id,
      item: monitorItem.originalItem
    });
    /** set new index for item */
    monitor.getItem().index = hoverIndex;
  }
};
class Container extends _react.default.PureComponent {
  constructor() {
    super(...arguments);
    this.setRootRef = node => this.rootNode = node;
    this.setChildRef = node => this.childNode = node;
  }
  render() {
    var {
      dataHook,
      className,
      connectDropTarget,
      children,
      style
    } = this.props;
    if (!connectDropTarget) {
      return null;
    }
    return connectDropTarget(/*#__PURE__*/_react.default.createElement("div", {
      "data-hook": dataHook,
      className: className,
      ref: this.setRootRef,
      style: style,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 123,
        columnNumber: 7
      }
    }, /*#__PURE__*/_react.default.cloneElement(children, {
      ref: this.setChildRef
    })));
  }
}
Container.propTypes = {
  dataHook: _propTypes.default.string,
  children: _propTypes.default.element.isRequired,
  className: _propTypes.default.string,
  containerId: _propTypes.default.string,
  groupName: _propTypes.default.string,
  index: _propTypes.default.number,
  onMoveOut: _propTypes.default.func,
  onDrop: _propTypes.default.func,
  onHover: _propTypes.default.func,
  droppable: _propTypes.default.bool
};
Container.defaultProps = {
  droppable: true
};
var _default = exports.default = (0, _reactDnd.DropTarget)(_types.ItemTypes.DRAGGABLE, target, connect => ({
  connectDropTarget: connect.dropTarget()
}))(Container);
//# sourceMappingURL=Container.js.map