"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
exports.__esModule = true;
exports.default = void 0;
var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
var _defaultTo = _interopRequireDefault(require("lodash/defaultTo"));
var _isEqual = _interopRequireDefault(require("lodash/isEqual"));
var _sortBy = _interopRequireDefault(require("lodash/sortBy"));
var _propTypes = require("../utils/propTypes");
var _InputWithOptions = _interopRequireDefault(require("../InputWithOptions"));
var _DropdownSt = require("./Dropdown.st.css");
var _propTypes2 = _interopRequireDefault(require("prop-types"));
var _DropdownLayout = require("../DropdownLayout/DropdownLayout");
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { (0, _defineProperty2.default)(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var NO_SELECTED_ID = null;
class Dropdown extends _InputWithOptions.default {
  constructor(props) {
    super(props);
    this.state = _objectSpread({
      value: '',
      selectedId: NO_SELECTED_ID
    }, Dropdown.getNextState(props, (0, _defaultTo.default)(props.selectedId, props.initialSelectedId)));
  }
  isSelectedIdControlled() {
    return typeof this.props.selectedId !== 'undefined';
  }
  static isOptionsEqual(optionsA, optionsB) {
    return (0, _isEqual.default)((0, _sortBy.default)(optionsA, 'id'), (0, _sortBy.default)(optionsB, 'id'));
  }
  getSelectedId() {
    return this.isSelectedIdControlled() ? this.props.selectedId : this.state.selectedId;
  }
  _onInputClicked(event) {
    if (this.props.onInputClicked) {
      this.props.onInputClicked(event);
    }
    if (this.props.readOnly) {
      return;
    }
    if (this.state.showOptions && Date.now() - this.state.lastOptionsShow > 200) {
      this.hideOptions();
    } else {
      this.showOptions();
    }
  }

  /**
   * Updates the value by the selectedId.
   * If selectedId is not found in options, then value is NOT changed.
   */
  static getNextState(props, selectedId) {
    if (typeof selectedId !== 'undefined') {
      var option = props.options.find(_option => {
        return _option.id === selectedId;
      });
      if (option) {
        var value = props.valueParser(option) || '';
        return {
          value,
          selectedId
        };
      }
    }
    return {
      value: '',
      selectedId: NO_SELECTED_ID
    };
  }
  UNSAFE_componentWillReceiveProps(nextProps) {
    if (nextProps.selectedId !== this.props.selectedId || !Dropdown.isOptionsEqual(this.props.options, nextProps.options)) {
      this.setState(Dropdown.getNextState(nextProps, nextProps.selectedId, this.state.selectedId));
    }
  }
  inputClasses() {
    var {
      noBorder
    } = this.props;
    return (0, _DropdownSt.st)(_DropdownSt.classes.showPointer, {
      noBorder
    });
  }
  dropdownAdditionalProps() {
    return {
      selectedId: this.getSelectedId(),
      value: this.state.value,
      tabIndex: -1,
      withArrow: false
    };
  }
  inputAdditionalProps() {
    return {
      disableEditing: true,
      value: this.state.value
    };
  }
  _onSelect(option) {
    if (!this.isSelectedIdControlled()) {
      this.setState({
        value: this.props.valueParser(option),
        selectedId: option.id
      });
    }
    super._onSelect(option);
  }
  _onChange(event) {
    this.setState({
      value: event.target.value
    });
    super._onChange(event);
  }
}
Dropdown.propTypes = {
  /** An initial selected option id. (Implies Uncontrolled mode) */
  initialSelectedId: _propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.number]),
  /** Associate a control with the regions that it controls. */
  ariaControls: _propTypes2.default.string,
  /** Associate a region with its descriptions. Similar to aria-controls but instead associating descriptions to the region and description identifiers are separated with a space. */
  ariaDescribedby: _propTypes2.default.string,
  /** Define a string that labels the current element in case where a text label is not visible on the screen. */
  ariaLabel: _propTypes2.default.string,
  /** Focus the element on mount (standard React input autoFocus). */
  autoFocus: _propTypes2.default.bool,
  /** Control the border style of input. */
  border: _propTypes2.default.oneOf(['standard', 'round', 'bottomLine', 'none']),
  /** Specifies a CSS class name to be appended to the component’s root element. */
  className: _propTypes2.default.string,
  /** Displays clear button (X) on a non-empty input. */
  clearButton: _propTypes2.default.bool,
  /** Closes DropdownLayout when option is selected. */
  closeOnSelect: _propTypes2.default.bool,
  /** Applies a data-hook HTML attribute that can be used in the tests. */
  dataHook: _propTypes2.default.string,
  /** Specifies whether input should be disabled or not. */
  disabled: _propTypes2.default.bool,
  /** Sets the width of the dropdown in pixels. */
  dropdownWidth: _propTypes2.default.string,
  /** Adds a fixed footer container at the bottom of options list in `<DropdownLayout/>`. */
  fixedFooter: _propTypes2.default.node,
  /** Adds a fixed header container at the top of options list in `<DropdownLayout/>`. */
  fixedHeader: _propTypes2.default.node,
  /** Highlights and scrolls view to the specified option when dropdown layout is opened. It does not select the specified option. */
  focusOnOption: _propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.number]),
  /** Scrolls view to the selected option when dropdown layout is opened. */
  focusOnSelectedOption: _propTypes2.default.bool,
  /** USED FOR TESTING. Forces focus state on the input. */
  forceFocus: _propTypes2.default.bool,
  /** USED FOR TESTING. Forces hover state on the input. */
  forceHover: _propTypes2.default.bool,
  /** Specifies whether there are more items to be loaded. */
  hasMore: _propTypes2.default.bool,
  /** Specifies whether status suffix should be hidden. */
  hideStatusSuffix: _propTypes2.default.bool,
  /** Assigns an unique identifier for the root element. */
  id: _propTypes2.default.string,
  /** Specifies whether lazy loading of the dropdown layout items is enabled. */
  infiniteScroll: _propTypes2.default.bool,
  /** Defines a callback function which is called on a request to render more list items. */
  loadMore: _propTypes2.default.func,
  /** Sets the default hover behavior:
   *  - `false` - no initially hovered list item
   *  - `true` - hover first selectable option
   *  - any `number/string` specify the id of an option to be hovered
   */
  markedOption: _propTypes2.default.oneOfType([_propTypes2.default.bool, _propTypes2.default.string, _propTypes2.default.number]),
  /** Sets the maximum height of the dropdownLayout in pixels. */
  maxHeightPixels: _propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.number]),
  /** Specifies whether input should have a dropdown menu arrow on the right side. */
  menuArrow: _propTypes2.default.bool,
  /** Sets the minimum width of dropdownLayout in pixels. */
  minWidthPixels: _propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.number]),
  /** Reference element data when a form is submitted. */
  name: _propTypes2.default.string,
  /** Render options list via native select element. */
  native: _propTypes2.default.bool,
  /** Specifies whether input shouldn’t have rounded corners on its left. */
  noLeftBorderRadius: _propTypes2.default.bool,
  /** Specifies whether input shouldn’t have rounded corners on its right. */
  noRightBorderRadius: _propTypes2.default.bool,
  /** Defines a standard input onBlur callback */
  onBlur: _propTypes2.default.func,
  /** Displays clear button (X) on a non-empty input and calls a callback function with no arguments. */
  onClear: _propTypes2.default.func,
  /** Defines a callback function which is called whenever the user presses the escape key. */
  onClose: _propTypes2.default.func,
  /** Defines a standard input onChange callback. */
  onChange: _propTypes2.default.func,
  /** Defines a callback function called on compositionstart/compositionend events. */
  onCompositionChange: _propTypes2.default.func,
  /** Defines a callback handler that is called when user presses -enter-. */
  onEnterPressed: _propTypes2.default.func,
  /** Defines a callback handler that is called when user presses -escape- */
  onEscapePressed: _propTypes2.default.func,
  /** Defines a standard input onFocus callback. */
  onFocus: _propTypes2.default.func,
  /** Defines a standard input onClick callback. */
  onInputClicked: _propTypes2.default.func,
  /** Defines a standard input onKeyDown callback. */
  onKeyDown: _propTypes2.default.func,
  /** Defines a standard input onKeyUp callback. */
  onKeyUp: _propTypes2.default.func,
  /** Defines a callback function which is called when user performs a submit action. Submit action triggers are:
   * "Enter", "Tab", [typing any defined delimiters], paste action.
   * `onManuallyInput(values: Array<string>): void - The array of strings is the result of splitting the input value by the given delimiters */
  onManuallyInput: _propTypes2.default.func,
  /** Defines a callback function which is called whenever the user enters dropdown layout with the mouse cursor. */
  onMouseEnter: _propTypes2.default.func,
  /** Defines a callback function which is called whenever the user exits from dropdown layout with a mouse cursor. */
  onMouseLeave: _propTypes2.default.func,
  /** Defines a callback function which is called whenever an option becomes focused (hovered/active). Receives the relevant option object from the original props.options array. */
  onOptionMarked: _propTypes2.default.func,
  /** Defines a callback function which is called when options dropdown is hidden. */
  onOptionsHide: _propTypes2.default.func,
  /** Defines a callback function which is called when options dropdown is shown. */
  onOptionsShow: _propTypes2.default.func,
  /** Defines a callback function which is called whenever user selects a different option in the list. */
  onSelect: _propTypes2.default.func,
  /** Array of objects:
   * - `id <string / number>` *required*: the id of the option, should be unique;
   * - value `<function / string / node>` *required*: can be a string, react element or a builder function;
   * - disabled `<bool>` *default value- false*: whether this option is disabled or not;
   * - linkTo `<string>`: when provided the option will be an anchor to the given value;
   * - title `<bool>`  *default value- false*  **deprecated**: please use `listItemSectionBuilder` for rendering a title;
   * - overrideStyle `<bool>` *default value- false*  **deprecated**: please use `overrideOptionStyle` for override option styles;
   * - overrideOptionStyle `<bool>` *default value- false* - when set to `true`, the option will be responsible to its own styles. No styles will be applied from the DropdownLayout itself;
   * - label `<string>`: the string displayed within an input when the option is selected. This is used when using `<DropdownLayout/>` with an `<Input/>`.
   */
  options: _propTypes2.default.arrayOf(_DropdownLayout.optionValidator),
  /** Handles container overflow. */
  overflow: _propTypes2.default.string,
  /** Sets a placeholder message to display. */
  placeholder: _propTypes2.default.string,
  /** Allows to pass all common popover props. */
  popoverProps: _propTypes2.default.shape({
    appendTo: _propTypes2.default.oneOf(['window', 'scrollParent', 'parent', 'viewport']),
    maxWidth: _propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.number]),
    minWidth: _propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.number]),
    flip: _propTypes2.default.bool,
    fixed: _propTypes2.default.bool,
    placement: _propTypes2.default.oneOf(['auto-start', 'auto', 'auto-end', 'top-start', 'top', 'top-end', 'right-start', 'right', 'right-end', 'bottom-end', 'bottom', 'bottom-start', 'left-end', 'left', 'left-start']),
    dynamicWidth: _propTypes2.default.bool
  }),
  /** Pass a component you want to show as the prefix of the input, e.g., text string, icon. */
  prefix: _propTypes2.default.node,
  /** Specifies whether input is read only. */
  readOnly: _propTypes2.default.bool,
  /** Specifies selected option by its id. */
  selectedId: _propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.number]),
  /** Controls whether to show options if input is empty. */
  showOptionsIfEmptyInput: _propTypes2.default.bool,
  /** Controls the size of the input */
  size: _propTypes2.default.oneOf(['small', 'medium', 'large']),
  /** Specify the status of a field. */
  status: _propTypes2.default.oneOf(['error', 'warning', 'loading']),
  /** Defines the message to display on status icon hover. If not given or empty there will be no tooltip. */
  statusMessage: _propTypes2.default.node,
  /** Pass a component you want to show as the suffix of the input, e.g., text string, icon. */
  suffix: _propTypes2.default.node,
  /** Indicates that element can be focused and where it participates in sequential keyboard navigation. */
  tabIndex: _propTypes2.default.number,
  /** Handles text overflow behavior. It can either clip (default) or display ellipsis. */
  textOverflow: _propTypes2.default.string,
  /** Controls placement of a status tooltip. */
  tooltipPlacement: _propTypes2.default.string,
  /** Defines a callback function that is triggered when one of the dropdown options are selected. This property should be used together with builders. */
  valueParser: _propTypes2.default.func
};
Dropdown.defaultProps = _InputWithOptions.default.defaultProps;
Dropdown.displayName = 'Dropdown';
var _default = exports.default = Dropdown;
//# sourceMappingURL=Dropdown.js.map