export default MarketingLayout;
/** Marketing layout is a layout designed to promote new features or display first time visit.
 * Component has title, description, action and illustration areas. */
declare class MarketingLayout extends React.PureComponent<any, any, any> {
    static displayName: string;
    static propTypes: {
        /** Applies a data-hook HTML attribute that can be used in the tests. */
        dataHook: PropTypes.Requireable<string>;
        /** Accepts image URL or a custom element to be displayed on the side of content. */
        image: PropTypes.Requireable<PropTypes.ReactNodeLike>;
        /** Specifies image area background color. Can be a keyword from color palette or any supported CSS color value (HEX, RGB, etc.). */
        imageBackgroundColor: PropTypes.Requireable<string>;
        /**
         * Controls the size of the marketing layout.<br/>
         */
        size: PropTypes.Requireable<string>;
        /** Controls content direction. */
        direction: PropTypes.Requireable<string>;
        /** Controls the vertical alignment of the content. */
        alignItems: PropTypes.Requireable<string>;
        /** Flips content layout. If true, image will be displayed on the left side of the content. */
        inverted: PropTypes.Requireable<boolean>;
        /** Sets marketing layout actions. Accepts single or multiple interactive components. Most commonly contain `<Button/>` or `<TextButton/>`. */
        actions: PropTypes.Requireable<PropTypes.ReactNodeLike>;
        /** Sets the marketing layout title. Accepts text string or a custom element. */
        title: PropTypes.Requireable<PropTypes.ReactNodeLike>;
        /** Sets the marketing layout description. Accepts text string or a custom element. */
        description: PropTypes.Requireable<PropTypes.ReactNodeLike>;
        /** Adds a container for a `<Badge/>` component at the top left corner. Affect component height. */
        badge: PropTypes.Requireable<PropTypes.ReactNodeLike>;
        /** Specifies whether the badge is hidden. Can be used to add additional vertical spacing, if no badge is given. */
        hiddenBadge: PropTypes.Requireable<boolean>;
        /** Enables padding inside image container. Use with `direction="horizontal"` layout only. */
        imagePadding: PropTypes.Requireable<boolean>;
    };
    static defaultProps: {
        size: string;
        alignItems: string;
        inverted: boolean;
        direction: string;
        hiddenBadge: boolean;
        imagePadding: boolean;
    };
    constructor(props: any);
    constructor(props: any, context: any);
    renderImagePlaceholder: () => React.JSX.Element;
    getBorderRadiusProps: () => {
        borderTopLeftRadius: string | undefined;
        borderTopRightRadius: string | undefined;
        borderBottomLeftRadius: string | undefined;
        borderBottomRightRadius: string | undefined;
    } | {
        borderTopLeftRadius?: undefined;
        borderTopRightRadius?: undefined;
        borderBottomLeftRadius?: undefined;
        borderBottomRightRadius?: undefined;
    };
    renderImage: () => React.JSX.Element | null;
    renderContent: () => React.JSX.Element;
    renderHorizontal(): (React.JSX.Element | null)[];
    renderVertical(): any[];
    render(): React.JSX.Element;
}
import React from 'react';
import PropTypes from 'prop-types';
//# sourceMappingURL=MarketingLayout.d.ts.map