"use strict";

exports.__esModule = true;
exports.getArrowShift = exports.detachClasses = exports.createComponentThatRendersItsChildren = exports.buildChildrenObject = exports.attachClasses = void 0;
exports.getParentNode = getParentNode;
exports.getScrollParent = getScrollParent;
exports.shouldAnimatePopover = exports.noop = exports.isStatelessComponent = exports.isReactElement = void 0;
var React = _interopRequireWildcard(require("react"));
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
var isTestEnv = process.env.NODE_ENV === 'test';
function getParentNode(element) {
  if (element.nodeName === 'HTML') {
    return element;
  }
  // @ts-ignore
  return element.parentNode || element.host;
}
function getStyleComputedProperty(element) {
  // NOTE: 1 DOM access here
  var window = element.ownerDocument.defaultView;
  // @ts-ignore
  return window.getComputedStyle(element, null);
}

// @ts-ignore
function getScrollParent(element) {
  // Return body, `getScroll` will take care to get the correct `scrollTop` from it
  if (!element) {
    return document.body;
  }
  switch (element.nodeName) {
    case 'HTML':
    case 'BODY':
      return element.ownerDocument.body;
    case '#document':
      // @ts-ignore
      return element.body;
    default:
  }

  // Firefox want us to check `-x` and `-y` variations as well
  var {
    overflow,
    overflowX,
    overflowY
  } = getStyleComputedProperty(element);
  if (/(auto|scroll|overlay)/.test(overflow + overflowY + overflowX)) {
    return element;
  }
  return getScrollParent(getParentNode(element));
}
var buildChildrenObject = (children, childrenObject) => {
  return React.Children.toArray(children).reduce((acc, child) => {
    if (! /*#__PURE__*/React.isValidElement(child)) {
      return acc;
    }
    if (!child.type || !child.type.displayName) {
      return acc;
    }
    var name = child.type.displayName.split('.').pop();
    // @ts-ignore
    acc[name] = child;
    return acc;
  }, childrenObject || {});
};
exports.buildChildrenObject = buildChildrenObject;
var createComponentThatRendersItsChildren = displayName => {
  var Element = _ref => {
    var {
      children
    } = _ref;
    return typeof children === 'string' ? /*#__PURE__*/React.createElement('div', {}, children) : children;
  };
  Element.displayName = displayName;
  return Element;
};
exports.createComponentThatRendersItsChildren = createComponentThatRendersItsChildren;
var noop = () => null;
exports.noop = noop;
var isReactElement = (child, Element) => {
  return child && child.type === Element;
};
exports.isReactElement = isReactElement;
var isStatelessComponent = Component => !(Component.prototype && Component.prototype.render);
exports.isStatelessComponent = isStatelessComponent;
var attachClasses = (node, classnames) => node && node.classList.add(...classnames.split(' '));
exports.attachClasses = attachClasses;
var detachClasses = (node, classnames) => node && node.classList.remove(...classnames.split(' '));
exports.detachClasses = detachClasses;
var shouldAnimatePopover = _ref2 => {
  var {
    timeout
  } = _ref2;
  if (typeof timeout === 'object') {
    var {
      enter,
      exit
    } = timeout;
    return typeof enter !== 'undefined' && typeof exit !== 'undefined' && (enter > 0 || exit > 0);
  }
  return !!timeout;
};
exports.shouldAnimatePopover = shouldAnimatePopover;
var getArrowShift = (shift, direction) => {
  if (!shift && !isTestEnv) {
    return {};
  }
  if (direction.startsWith('top') || direction.startsWith('bottom')) {
    return {
      left: "".concat(shift, "px")
    };
  }
  if (direction.startsWith('left') || direction.startsWith('right')) {
    return {
      top: "".concat(shift, "px")
    };
  }

  // Arrow can't be shifted when using automatic positioning
  return {};
};
exports.getArrowShift = getArrowShift;
//# sourceMappingURL=utils.js.map