"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
exports.__esModule = true;
exports.tableActionCellUniDriverFactory = void 0;
var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));
var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
var _unidriver = require("../test-utils/utils/unidriver");
var _constants = require("./constants");
var _ButtonUni = require("../Button/Button.uni.driver");
var _TooltipUni = require("../Tooltip/Tooltip.uni.driver");
var _PopoverMenuUni = require("../PopoverMenu/PopoverMenu.uni.driver");
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { (0, _defineProperty2.default)(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var tableActionCellUniDriverFactory = (base, body) => {
  var getPrimaryActionButtonVisibility = () => (0, _unidriver.getDataAttributeValue)((0, _unidriver.findByHook)(base, _constants.dataHooks.primaryActionWrapper), 'data-display');
  var getPrimaryActionButtonDriver = () => (0, _ButtonUni.buttonDriverFactory)((0, _unidriver.findByHook)(base, _constants.dataHooks.primaryAction));
  var getVisibleActionTooltipDriver = actionIndex => (0, _TooltipUni.tooltipDriverFactory)((0, _unidriver.findByHookAtIndex)(base, _constants.dataHooks.visibleActionTooltip, actionIndex), body);
  var getVisibleActionByDataHookTooltipDriver = dataHook => (0, _TooltipUni.tooltipDriverFactory)((0, _unidriver.findByHook)(base, dataHook), body);
  var getVisibleActionButtonDriver = actionIndex => (0, _ButtonUni.buttonDriverFactory)((0, _unidriver.findByHookAtIndex)(base, _constants.dataHooks.visibleAction, actionIndex));
  var getVisibleActionByDataHookButtonDriver = dataHook => (0, _ButtonUni.buttonDriverFactory)((0, _unidriver.findByHook)(base, dataHook));
  var getHiddenActionsPopoverMenuDriver = () => (0, _PopoverMenuUni.PopoverMenuDriver)((0, _unidriver.findByHook)(base, _constants.dataHooks.popoverMenu), body);
  return _objectSpread(_objectSpread({}, (0, _unidriver.baseUniDriverFactory)(base, body)), {}, {
    /**
     * Get the driver of the primary action <Button/> from the action column
     * @returns {Promise<buttonDriverFactory>}
     */
    getPrimaryActionButtonDriver,
    /**
     * Gets primary action visibility value
     * @returns {Promise<'onHover' | 'always'>}
     */
    getPrimaryActionButtonVisibility,
    /**
     * Clicks the primary action button of the action column
     * @returns {Promise<void>}
     */
    clickPrimaryActionButton: function () {
      var _clickPrimaryActionButton = (0, _asyncToGenerator2.default)(function* () {
        return yield getPrimaryActionButtonDriver().click();
      });
      function clickPrimaryActionButton() {
        return _clickPrimaryActionButton.apply(this, arguments);
      }
      return clickPrimaryActionButton;
    }(),
    /**
     * Checks whether the primary action button is disabled
     * @returns {Promise<boolean>}
     */
    getIsPrimaryActionButtonDisabled: function () {
      var _getIsPrimaryActionButtonDisabled = (0, _asyncToGenerator2.default)(function* () {
        return yield getPrimaryActionButtonDriver().isButtonDisabled();
      });
      function getIsPrimaryActionButtonDisabled() {
        return _getIsPrimaryActionButtonDisabled.apply(this, arguments);
      }
      return getIsPrimaryActionButtonDisabled;
    }(),
    /**
     * Checks whether the primary action button has an prefix icon
     * @returns {Promise<boolean>}
     */
    primaryActionButtonPrefixIconExists: function () {
      var _primaryActionButtonPrefixIconExists = (0, _asyncToGenerator2.default)(function* () {
        return yield getPrimaryActionButtonDriver().isPrefixIconExists();
      });
      function primaryActionButtonPrefixIconExists() {
        return _primaryActionButtonPrefixIconExists.apply(this, arguments);
      }
      return primaryActionButtonPrefixIconExists;
    }(),
    /**
     * Checks whether the primary action button has an suffix icon
     * @returns {Promise<boolean>}
     */
    primaryActionButtonSuffixIconExists: function () {
      var _primaryActionButtonSuffixIconExists = (0, _asyncToGenerator2.default)(function* () {
        return yield getPrimaryActionButtonDriver().isSuffixIconExists();
      });
      function primaryActionButtonSuffixIconExists() {
        return _primaryActionButtonSuffixIconExists.apply(this, arguments);
      }
      return primaryActionButtonSuffixIconExists;
    }(),
    /**
     * Get the number of the visible secondary actions
     * @returns {Promise<number>} number of visible secondary actions
     */
    getVisibleActionsCount: () => (0, _unidriver.countByHook)(base, _constants.dataHooks.visibleAction),
    /**
     * Get the number of hidden secondary actions (in the <PopoverMenu/>, requires it to be open)
     * @returns {Promise<number>} number of hidden secondary actions
     */
    getHiddenActionsCount: () => getHiddenActionsPopoverMenuDriver().childrenCount(),
    /**
     * Gets a specific visible secondary action <Tooltip/> driver
     * @param {actionIndex} actionIndex
     * @returns {Promise<tooltipDriverFactory>}
     */
    getVisibleActionTooltipDriver,
    /**
     * Get the driver of a specific visible secondary action <Tooltip/> by its specified dataHook
     * @param {dataHook} tooltip dataHook
     * @returns {Promise<tooltipDriverFactory>}
     */
    getVisibleActionByDataHookTooltipDriver,
    /**
     * Get the driver of a specific visible secondary action <Button/>
     * @param {actionIndex} actionIndex
     * @returns {Promise<buttonDriverFactory>}
     */
    getVisibleActionButtonDriver,
    /**
     * Gets a specific visible secondary action <Button/> driver by its specified dataHook
     * @param {dataHook} button dataHook
     * @returns {Promise<buttonDriverFactory>} visible action button driver
     */
    getVisibleActionByDataHookButtonDriver,
    /**
     * Gets the hidden secondary action <PopoverMenu/> driver
     * @returns {Promise<PopoverMenuUniDriver>}
     */
    getHiddenActionsPopoverMenuDriver,
    /**
     * Clicks on a visible secondary action
     * @param {actionIndex} actionIndex
     * @returns {Promise<void>}
     */
    clickVisibleAction: actionIndex => getVisibleActionButtonDriver(actionIndex).click(),
    /**
     * Clicks on a visible secondary action by its specified dataHook
     * @param {actionDataHook} actionDataHook
     * @returns {Promise<void>}
     */
    clickVisibleActionByDataHook: actionDataHook => getVisibleActionByDataHookButtonDriver(actionDataHook).click(),
    /**
     * Clicks on the hidden secondary actions <PopoverMenu/>
     * @returns {Promise<void>}
     */
    clickPopoverMenu: () => getHiddenActionsPopoverMenuDriver().getTriggerElement(_constants.dataHooks.triggerElement).click(),
    /**
     * Clicks on a hidden secondary action (requires the <PopoverMenu/> to be open)
     * @param {actionIndex} actionIndex
     * @returns {Promise<void>}
     */
    clickHiddenAction: actionIndex => getHiddenActionsPopoverMenuDriver().clickAtChild(actionIndex),
    /**
     * Clicks hidden action by data hook
     * @param {actionDataHook} actionDataHook
     * @returns {Promise<void>}
     */
    clickHiddenActionByDataHook: actionDataHook => getHiddenActionsPopoverMenuDriver().clickAtChildByDataHook(actionDataHook),
    /**
     * Gets tooltip text of more actions toggle button
     * @return {Promise<string>}
     */
    getMoreActionsTooltipText: () => base.attr('data-more-actions-tooltip-text')
  });
};
exports.tableActionCellUniDriverFactory = tableActionCellUniDriverFactory;
//# sourceMappingURL=TableActionCell.uni.driver.js.map