"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
exports.__esModule = true;
exports.default = exports.BASE_ATLAS_URL = void 0;
var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));
var _react = require("react");
var _http = require("@wix/ambassador-wix-atlas-service-web/http");
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { (0, _defineProperty2.default)(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var BASE_ATLAS_URL = exports.BASE_ATLAS_URL = '/wix-atlas-service-web';

// Client for fetching autocomplete predictions from Atlas
var useAtlasClient = function useAtlasClient() {
  var {
    /** Custom domain to retrieve predictions from  */
    baseUrl = BASE_ATLAS_URL,
    /** Authorization token to pass to the Atlas Service */
    token,
    /** Language to pass to the Atlas Service */
    language,
    /** Locale header to pass to the Atlas Service */
    locale
  } = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  // languageHeader to set language for Atlas Service 'x-wix-linguist': language|locale|isPrimaryLanguage|token
  var languageHeader = "".concat(language, "|").concat(locale, "|false|").concat(token);
  var atlas = (0, _react.useMemo)(() => (0, _http.WixAtlasServiceWeb)(baseUrl), [baseUrl]);
  // Atlas Ambassador autocomplete service (memoized)
  var autocompleteService = (0, _react.useMemo)(() => atlas.AutocompleteServiceV2()({
    Authorization: token,
    'x-wix-linguist': languageHeader
  }), [atlas, token, languageHeader]);
  // Atlas Ambassador places service (memoized)
  var placesService = (0, _react.useMemo)(() => atlas.PlacesServiceV2()({
    Authorization: token,
    'x-wix-linguist': languageHeader
  }), [atlas, token, languageHeader]);
  // Atlas Ambassador location service (memoized)
  var locationService = (0, _react.useMemo)(() => atlas.LocationServiceV2()({
    Authorization: token,
    'x-wix-linguist': languageHeader
  }), [atlas, token, languageHeader]);
  var fetchPredictions = (0, _react.useCallback)(/*#__PURE__*/function () {
    var _ref = (0, _asyncToGenerator2.default)(function* (value, requestOptions) {
      // fetch autocomplete predictions based on value
      var {
        predictions
      } = yield autocompleteService.predict(_objectSpread(_objectSpread({}, requestOptions), {}, {
        input: value
      }));
      return predictions;
    });
    return function (_x, _x2) {
      return _ref.apply(this, arguments);
    };
  }(), [autocompleteService]);
  var getAddress = (0, _react.useCallback)(/*#__PURE__*/function () {
    var _ref2 = (0, _asyncToGenerator2.default)(function* (searchId) {
      var {
        place: {
          address
        }
      } = yield placesService.getPlace({
        searchId
      });
      return address;
    });
    return function (_x3) {
      return _ref2.apply(this, arguments);
    };
  }(), [placesService]);
  var searchAddresses = (0, _react.useCallback)(/*#__PURE__*/function () {
    var _ref3 = (0, _asyncToGenerator2.default)(function* (query) {
      var {
        searchResults
      } = yield locationService.search({
        query
      });
      var addresses = searchResults.map(_ref4 => {
        var {
          address
        } = _ref4;
        return address;
      });
      return addresses;
    });
    return function (_x4) {
      return _ref3.apply(this, arguments);
    };
  }(), [locationService]);
  return {
    /** callback that fetches predictions from Atlas
    * @param {string} value Input text we want predictions for.
    * @param {AtlasRequestOptions} requestOptions (optional) Options to customize predictions: {
      *  @property { filterType: "zip_code" | "country_code", filterValue: string } filterBy
              (optional) filter results by country or zip code;
      *  @property {latitude: number, longitude: number} location
              (optional) the point around which you wish to retrieve place information;
      *  @property {latitude: number, longitude: number} origin
              (optional) the origin point from which to calculate straight-line distance to the destination;
      *  @property {number} radius (optional) the distance (in meters) within which to return place results;
    * }
    * @returns {Promise<Prediction[]>} */
    fetchPredictions,
    /** callback that fetches details for a place given its atlas `searchId`
     * @param {string} searchId identifier for atlas prediction result we want to get additional details for
     * @returns {Promise<Address>} */
    getAddress,
    /** callback that searches for addresses matching given value
     * @param {string} query Input text to search address for
     * @returns {Promise<Address[]>}
     */
    searchAddresses,
    /** whether component is ready */
    ready: true
  };
};
var _default = exports.default = useAtlasClient;
//# sourceMappingURL=useAtlasClient.js.map