import * as React from 'react';
type ButtonTypes = 'textButton' | 'button' | 'node';
type ShowLabels = 'hover' | 'always';
type Skins = 'standard' | 'light' | 'neutral';
type Sizes = 'tiny' | 'small' | 'medium' | 'large';
type HorizontalPaddings = 'none' | 'tiny' | 'small' | 'medium' | 'large';
type TransitionSpeeds = 'slow' | 'medium' | 'fast';
export interface AccordionItemType extends AccordionItemProps {
    render?: (uncontrolledProps: AccordionItemCommonProps, internalProps: AccordionItemInternalProps) => React.ReactNode;
}
export interface AccordionState {
    openIndexes: number[];
}
export interface AccordionProps {
    /** Applied as data-hook HTML attribute that can be used to create driver in testing */
    dataHook?: string;
    /** Hide Accordion shadow effect   */
    hideShadow?: boolean;
    /** Change horizontal padding   */
    horizontalPadding?: 'none' | 'tiny' | 'small' | 'medium' | 'large';
    /** Provide items
     * - Available items props:
     * ```javascript
     * {
     * render?: func;
       title?: React.ReactNode;
       subtitle?: React.ReactNode;
       icon?: React.ReactNode;
       children?: React.ReactNode;
       expandLabel?: React.ReactNode;
       collapseLabel?: React.ReactNode;
       showLabel?: 'hover' | 'always';
       buttonType?: 'textButton' | 'button' | 'node';
       disabled?: boolean;
       onToggle?: React.MouseEventHandler<HTMLElement>;
       onMouseEnter?: React.MouseEventHandler<HTMLElement>;
       onMouseLeave?: React.MouseEventHandler<HTMLElement>;
       open?: boolean;
       initiallyOpen?: boolean;
     * }
        ```
     */
    items?: AccordionItemType[];
    /** allow multiple rows to be opened simultaneously   */
    multiple?: boolean;
    /** Callback fired immediately after the animation is started */
    onAnimationEnter?: () => void;
    /** Callback fired immediately after the animation is ended */
    onAnimationExit?: () => void;
    /** Change items size   */
    size?: 'tiny' | 'small' | 'medium' | 'large';
    /** Accordion skin color   */
    skin?: 'standard' | 'light' | 'neutral';
    /** Change expand and collapse animation speed   */
    transitionSpeed?: 'slow' | 'medium' | 'fast';
}
export declare const accordionItemBuilder: (props?: AccordionItemCommonProps) => (options?: AccordionItemInternalProps) => {
    render(): React.ReactNode;
};
export declare const accordionSectionItemBuilder: (props?: AccordionSectionItemProps['title']) => (options?: AccordionSectionItemProps['size']) => {
    render(): React.ReactNode;
};
export interface AccordionItemCommonProps {
    key?: string | number;
    open?: boolean;
    initiallyOpen?: boolean;
    disabled?: boolean;
    title?: React.ReactNode;
    subtitle?: React.ReactNode;
    /**
     * @deprecated
     * use 'prefix' instead
     */
    icon?: React.ReactNode;
    /** Node rendered at the start of the item */
    prefix?: React.ReactNode;
    /** Node rendered at the end of the item */
    suffix?: React.ReactNode;
    children?: React.ReactNode;
    expandLabel?: React.ReactNode;
    collapseLabel?: React.ReactNode;
    /** controls where the caret is positioned */
    toggleIconPlacement?: 'start' | 'end';
    className?: string;
    buttonType?: ButtonTypes;
    showLabel?: ShowLabels;
    onToggle?: React.MouseEventHandler<HTMLElement>;
    onMouseEnter?: React.MouseEventHandler<HTMLElement>;
    onMouseLeave?: React.MouseEventHandler<HTMLElement>;
}
export interface AccordionItemInternalProps {
    key?: string | number;
    last?: boolean;
    hideShadow?: boolean;
    className?: string;
    skin?: Skins;
    size?: Sizes;
    onAnimationEnter?: () => void;
    onAnimationExit?: () => void;
    transitionSpeed?: TransitionSpeeds;
    horizontalPadding?: HorizontalPaddings;
    children?: React.ReactNode;
}
export type AccordionItemProps = AccordionItemCommonProps & AccordionItemInternalProps;
export interface AccordionItemCaretProps extends Pick<AccordionItemCommonProps, 'buttonType' | 'expandLabel' | 'collapseLabel' | 'showLabel' | 'open' | 'disabled'>, Pick<AccordionItemInternalProps, 'skin'> {
    hover: boolean;
}
export interface AccordionSectionItemProps extends AccordionItemProps {
}
export {};
//# sourceMappingURL=Accordion.types.d.ts.map